import { useEffect, useState } from "react";
import useLocalStorage from "./useLocalStorage";

/**
 * A hook to toggle between light and dark theme and store the value in local storage.
 * @returns {isDark, toggleTheme} - Returns a boolean indicating if dark mode is active and a function to toggle the theme.
 */
const useTheme = (): [boolean, () => void] => {
	// Initialize theme from local storage or default value
	const [theme, setTheme] = useLocalStorage<string>("theme", "light");

	// Determine if the current theme is dark
	const [isDark, setIsDark] = useState<boolean>(theme === "dark");

	const toggleTheme = () => {
		const newTheme = theme === "light" ? "dark" : "light";
		setTheme(newTheme);
		setIsDark(newTheme === "dark");
		document.documentElement.dataset.theme = newTheme;
	};

	// Apply the theme on component mount
	useEffect(() => {
		document.documentElement.dataset.theme = theme;
	}, [theme]); // Re-run effect when theme changes

	return [isDark, toggleTheme];
};

export default useTheme;
